==> org-lsst-ccs-subsystem-fcs-main-1.4.6-sources.jar: org/lsst/ccs/subsystems/fcs/testbench/BridgeForCPPMTestBench.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.testbench;

import org.lsst.ccs.subsystems.fcs.drivers.BridgeToCanOpenHardware;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenEPOS24;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenEPOS70;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenPlutoGateway;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenProxy;

/**
 *
 * @author virieux
 */
public class BridgeForCPPMTestBench extends BridgeToCanOpenHardware {
    
    CanOpenPlutoGateway plutoGateway;
    
    CanOpenEPOS70 linearRailMasterController;
    CanOpenEPOS70 linearRailSlaveController;
    CanOpenEPOS24 onlineClampController;

    public BridgeForCPPMTestBench(String aName, int aTickMillis, 
            CanOpenProxy tcpProxy, 
            CanOpenPlutoGateway plutoGW, 
            CanOpenEPOS70 anEpos, 
            CanOpenEPOS70 anotherEpos,
            CanOpenEPOS24 onlineClampController) {
        super(aName, aTickMillis, tcpProxy);
        this.plutoGateway = plutoGW;
        this.linearRailMasterController = anEpos;
        this.linearRailSlaveController = anotherEpos;
        this.onlineClampController = onlineClampController;
    }
    
    public String toString() {
        StringBuilder sb = new StringBuilder(super.toString());
        sb.append(", plutoGateway=");sb.append(String.valueOf(plutoGateway.toString()));
        sb.append(", linearRailMasterController=");sb.append(String.valueOf(linearRailMasterController.toString()));
        sb.append(", linearRailSlaveController=");sb.append(String.valueOf(linearRailSlaveController.toString()));
        sb.append(", onlineClampController=");sb.append(String.valueOf(onlineClampController.toString()));
        return sb.toString();
    }
    
}

==> org-lsst-ccs-subsystem-fcs-main-2.0.1-sources.jar: org/lsst/ccs/subsystems/fcs/testbench/BridgeForCPPMTestBench.java <==
/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */
package org.lsst.ccs.subsystems.fcs.testbench;

import org.lsst.ccs.subsystems.fcs.drivers.BridgeToCanOpenHardware;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenEPOS24;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenEPOS70;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenPlutoGateway;
import org.lsst.ccs.subsystems.fcs.drivers.CanOpenProxy;

/**
 *
 * @author virieux
 */
public class BridgeForCPPMTestBench extends BridgeToCanOpenHardware {
    
    CanOpenPlutoGateway plutoGateway;
    
    CanOpenEPOS70 linearRailMasterController;
    CanOpenEPOS70 linearRailSlaveController;
    CanOpenEPOS24 onlineClampController;
    CanOpenEPOS24 latchXminusController;

    public BridgeForCPPMTestBench(String aName, int aTickMillis, 
            CanOpenProxy tcpProxy, 
            CanOpenPlutoGateway plutoGW, 
            CanOpenEPOS70 anEpos, 
            CanOpenEPOS70 anotherEpos,
            CanOpenEPOS24 onlineClampController,
            CanOpenEPOS24 latchController) {
        super(aName, aTickMillis, tcpProxy);
        this.plutoGateway = plutoGW;
        this.linearRailMasterController = anEpos;
        this.linearRailSlaveController = anotherEpos;
        this.onlineClampController = onlineClampController;
        this.latchXminusController = latchController;
        }
    
    public String toString() {
        StringBuilder sb = new StringBuilder(super.toString());
        sb.append(", plutoGateway=");sb.append(String.valueOf(plutoGateway.toString()));
        sb.append(", linearRailMasterController=");sb.append(String.valueOf(linearRailMasterController.toString()));
        sb.append(", linearRailSlaveController=");sb.append(String.valueOf(linearRailSlaveController.toString()));
        sb.append(", onlineClampController=");sb.append(String.valueOf(onlineClampController.toString()));
        sb.append(", latchController=");sb.append(String.valueOf(latchXminusController.toString()));
        return sb.toString();
    }
    
}
